==> zio-aws-mediatailor_3-5.17.103.1-sources.jar: zio/aws/mediatailor/model/DeleteChannelPolicyRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteChannelPolicyRequest(channelName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DeleteChannelPolicyRequest = {
    import DeleteChannelPolicyRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DeleteChannelPolicyRequest
      .builder()
      .channelName(__string.unwrap(channelName): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.DeleteChannelPolicyRequest.ReadOnly =
    zio.aws.mediatailor.model.DeleteChannelPolicyRequest.wrap(buildAwsValue())
}
object DeleteChannelPolicyRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DeleteChannelPolicyRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.DeleteChannelPolicyRequest =
      zio.aws.mediatailor.model.DeleteChannelPolicyRequest(channelName)
    def channelName: __string
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteChannelPolicyRequest
  ) extends zio.aws.mediatailor.model.DeleteChannelPolicyRequest.ReadOnly {
    override val channelName: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.channelName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteChannelPolicyRequest
  ): zio.aws.mediatailor.model.DeleteChannelPolicyRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.17.295.5-sources.jar: zio/aws/mediatailor/model/DeleteChannelPolicyRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteChannelPolicyRequest(channelName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DeleteChannelPolicyRequest = {
    import DeleteChannelPolicyRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DeleteChannelPolicyRequest
      .builder()
      .channelName(channelName: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.DeleteChannelPolicyRequest.ReadOnly =
    zio.aws.mediatailor.model.DeleteChannelPolicyRequest.wrap(buildAwsValue())
}
object DeleteChannelPolicyRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DeleteChannelPolicyRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.DeleteChannelPolicyRequest =
      zio.aws.mediatailor.model.DeleteChannelPolicyRequest(channelName)
    def channelName: __string
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteChannelPolicyRequest
  ) extends zio.aws.mediatailor.model.DeleteChannelPolicyRequest.ReadOnly {
    override val channelName: __string = impl.channelName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteChannelPolicyRequest
  ): zio.aws.mediatailor.model.DeleteChannelPolicyRequest.ReadOnly =
    new Wrapper(impl)
}
